pub trait AttributeLike<'c> {
Show 32 methods
// Required method
fn to_raw(&self) -> MlirAttribute;
// Provided methods
fn context(&self) -> ContextRef<'c> { ... }
fn type(&self) -> Type<'c> { ... }
fn type_id(&self) -> TypeId<'c> { ... }
fn dump(&self) { ... }
fn is_affine_map(&self) -> bool { ... }
fn is_array(&self) -> bool { ... }
fn is_bool(&self) -> bool { ... }
fn is_dense_bool_array(&self) -> bool { ... }
fn is_dense_elements(&self) -> bool { ... }
fn is_dense_f32_array(&self) -> bool { ... }
fn is_dense_f64_array(&self) -> bool { ... }
fn is_dense_fp_elements(&self) -> bool { ... }
fn is_dense_i16_array(&self) -> bool { ... }
fn is_dense_i32_array(&self) -> bool { ... }
fn is_dense_i64_array(&self) -> bool { ... }
fn is_dense_i8_array(&self) -> bool { ... }
fn is_dense_int_elements(&self) -> bool { ... }
fn is_dictionary(&self) -> bool { ... }
fn is_elements(&self) -> bool { ... }
fn is_flat_symbol_ref(&self) -> bool { ... }
fn is_float(&self) -> bool { ... }
fn is_integer(&self) -> bool { ... }
fn is_integer_set(&self) -> bool { ... }
fn is_opaque(&self) -> bool { ... }
fn is_sparse_elements(&self) -> bool { ... }
fn is_sparse_tensor_encoding_attr(&self) -> bool { ... }
fn is_strided_layout(&self) -> bool { ... }
fn is_string(&self) -> bool { ... }
fn is_symbol_ref(&self) -> bool { ... }
fn is_type(&self) -> bool { ... }
fn is_unit(&self) -> bool { ... }
}Expand description
A trait for attribute-like types.
Required Methods
Sourcefn to_raw(&self) -> MlirAttribute
fn to_raw(&self) -> MlirAttribute
Converts a attribute into a raw object.
Provided Methods
Sourcefn context(&self) -> ContextRef<'c>
fn context(&self) -> ContextRef<'c>
Returns a context.
Sourcefn is_affine_map(&self) -> bool
fn is_affine_map(&self) -> bool
Returns true if an attribute is affine map.
Sourcefn is_dense_bool_array(&self) -> bool
fn is_dense_bool_array(&self) -> bool
Returns true if an attribute is dense bool array.
Sourcefn is_dense_elements(&self) -> bool
fn is_dense_elements(&self) -> bool
Returns true if an attribute is dense elements.
Sourcefn is_dense_f32_array(&self) -> bool
fn is_dense_f32_array(&self) -> bool
Returns true if an attribute is dense f32 array.
Sourcefn is_dense_f64_array(&self) -> bool
fn is_dense_f64_array(&self) -> bool
Returns true if an attribute is dense f64 array.
Sourcefn is_dense_fp_elements(&self) -> bool
fn is_dense_fp_elements(&self) -> bool
Returns true if an attribute is dense fp elements.
Sourcefn is_dense_i16_array(&self) -> bool
fn is_dense_i16_array(&self) -> bool
Returns true if an attribute is dense i16 array.
Sourcefn is_dense_i32_array(&self) -> bool
fn is_dense_i32_array(&self) -> bool
Returns true if an attribute is dense i32 array.
Sourcefn is_dense_i64_array(&self) -> bool
fn is_dense_i64_array(&self) -> bool
Returns true if an attribute is dense i64 array.
Sourcefn is_dense_i8_array(&self) -> bool
fn is_dense_i8_array(&self) -> bool
Returns true if an attribute is dense i8 array.
Sourcefn is_dense_int_elements(&self) -> bool
fn is_dense_int_elements(&self) -> bool
Returns true if an attribute is dense int elements.
Sourcefn is_dictionary(&self) -> bool
fn is_dictionary(&self) -> bool
Returns true if an attribute is dictionary.
Sourcefn is_elements(&self) -> bool
fn is_elements(&self) -> bool
Returns true if an attribute is elements.
Sourcefn is_flat_symbol_ref(&self) -> bool
fn is_flat_symbol_ref(&self) -> bool
Returns true if an attribute is flat symbol ref.
Sourcefn is_integer(&self) -> bool
fn is_integer(&self) -> bool
Returns true if an attribute is integer.
Sourcefn is_integer_set(&self) -> bool
fn is_integer_set(&self) -> bool
Returns true if an attribute is integer set.
Sourcefn is_sparse_elements(&self) -> bool
fn is_sparse_elements(&self) -> bool
Returns true if an attribute is sparse elements.
Sourcefn is_sparse_tensor_encoding_attr(&self) -> bool
fn is_sparse_tensor_encoding_attr(&self) -> bool
Returns true if an attribute is sparse tensor encoding attr.
Sourcefn is_strided_layout(&self) -> bool
fn is_strided_layout(&self) -> bool
Returns true if an attribute is strided layout.
Sourcefn is_symbol_ref(&self) -> bool
fn is_symbol_ref(&self) -> bool
Returns true if an attribute is symbol ref.